import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CertificateConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#account_key_pem Certificate#account_key_pem}.
     *
     * @stability stable
     */
    readonly accountKeyPem: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#certificate_p12_password Certificate#certificate_p12_password}.
     *
     * @stability stable
     */
    readonly certificateP12Password?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#certificate_request_pem Certificate#certificate_request_pem}.
     *
     * @stability stable
     */
    readonly certificateRequestPem?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#common_name Certificate#common_name}.
     *
     * @stability stable
     */
    readonly commonName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#disable_complete_propagation Certificate#disable_complete_propagation}.
     *
     * @stability stable
     */
    readonly disableCompletePropagation?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#key_type Certificate#key_type}.
     *
     * @stability stable
     */
    readonly keyType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#min_days_remaining Certificate#min_days_remaining}.
     *
     * @stability stable
     */
    readonly minDaysRemaining?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#must_staple Certificate#must_staple}.
     *
     * @stability stable
     */
    readonly mustStaple?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#pre_check_delay Certificate#pre_check_delay}.
     *
     * @stability stable
     */
    readonly preCheckDelay?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#preferred_chain Certificate#preferred_chain}.
     *
     * @stability stable
     */
    readonly preferredChain?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#recursive_nameservers Certificate#recursive_nameservers}.
     *
     * @stability stable
     */
    readonly recursiveNameservers?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#revoke_certificate_on_destroy Certificate#revoke_certificate_on_destroy}.
     *
     * @stability stable
     */
    readonly revokeCertificateOnDestroy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#subject_alternative_names Certificate#subject_alternative_names}.
     *
     * @stability stable
     */
    readonly subjectAlternativeNames?: string[];
    /**
     * dns_challenge block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#dns_challenge Certificate#dns_challenge}
     *
     * @stability stable
     */
    readonly dnsChallenge?: CertificateDnsChallenge[];
    /**
     * http_challenge block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#http_challenge Certificate#http_challenge}
     *
     * @stability stable
     */
    readonly httpChallenge?: CertificateHttpChallenge;
    /**
     * http_memcached_challenge block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#http_memcached_challenge Certificate#http_memcached_challenge}
     *
     * @stability stable
     */
    readonly httpMemcachedChallenge?: CertificateHttpMemcachedChallenge;
    /**
     * http_webroot_challenge block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#http_webroot_challenge Certificate#http_webroot_challenge}
     *
     * @stability stable
     */
    readonly httpWebrootChallenge?: CertificateHttpWebrootChallenge;
    /**
     * tls_challenge block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#tls_challenge Certificate#tls_challenge}
     *
     * @stability stable
     */
    readonly tlsChallenge?: CertificateTlsChallenge;
}
/**
 * @stability stable
 */
export interface CertificateDnsChallenge {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#config Certificate#config}.
     *
     * @stability stable
     */
    readonly config?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#provider Certificate#provider}.
     *
     * @stability stable
     */
    readonly provider: string;
}
export declare function certificateDnsChallengeToTerraform(struct?: CertificateDnsChallenge): any;
/**
 * @stability stable
 */
export interface CertificateHttpChallenge {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#port Certificate#port}.
     *
     * @stability stable
     */
    readonly port?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#proxy_header Certificate#proxy_header}.
     *
     * @stability stable
     */
    readonly proxyHeader?: string;
}
export declare function certificateHttpChallengeToTerraform(struct?: CertificateHttpChallengeOutputReference | CertificateHttpChallenge): any;
/**
 * @stability stable
 */
export declare class CertificateHttpChallengeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateHttpChallenge | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateHttpChallenge | undefined);
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
    private _proxyHeader?;
    /**
     * @stability stable
     */
    get proxyHeader(): string;
    /**
     * @stability stable
     */
    set proxyHeader(value: string);
    /**
     * @stability stable
     */
    resetProxyHeader(): void;
    /**
     * @stability stable
     */
    get proxyHeaderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CertificateHttpMemcachedChallenge {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#hosts Certificate#hosts}.
     *
     * @stability stable
     */
    readonly hosts: string[];
}
export declare function certificateHttpMemcachedChallengeToTerraform(struct?: CertificateHttpMemcachedChallengeOutputReference | CertificateHttpMemcachedChallenge): any;
/**
 * @stability stable
 */
export declare class CertificateHttpMemcachedChallengeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateHttpMemcachedChallenge | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateHttpMemcachedChallenge | undefined);
    private _hosts?;
    /**
     * @stability stable
     */
    get hosts(): string[];
    /**
     * @stability stable
     */
    set hosts(value: string[]);
    /**
     * @stability stable
     */
    get hostsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CertificateHttpWebrootChallenge {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#directory Certificate#directory}.
     *
     * @stability stable
     */
    readonly directory: string;
}
export declare function certificateHttpWebrootChallengeToTerraform(struct?: CertificateHttpWebrootChallengeOutputReference | CertificateHttpWebrootChallenge): any;
/**
 * @stability stable
 */
export declare class CertificateHttpWebrootChallengeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateHttpWebrootChallenge | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateHttpWebrootChallenge | undefined);
    private _directory?;
    /**
     * @stability stable
     */
    get directory(): string;
    /**
     * @stability stable
     */
    set directory(value: string);
    /**
     * @stability stable
     */
    get directoryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CertificateTlsChallenge {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate.html#port Certificate#port}.
     *
     * @stability stable
     */
    readonly port?: number;
}
export declare function certificateTlsChallengeToTerraform(struct?: CertificateTlsChallengeOutputReference | CertificateTlsChallenge): any;
/**
 * @stability stable
 */
export declare class CertificateTlsChallengeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CertificateTlsChallenge | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CertificateTlsChallenge | undefined);
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/acme/r/certificate.html acme_certificate}.
 *
 * @stability stable
 */
export declare class Certificate extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/acme/r/certificate.html acme_certificate} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CertificateConfig);
    private _accountKeyPem?;
    /**
     * @stability stable
     */
    get accountKeyPem(): string;
    /**
     * @stability stable
     */
    set accountKeyPem(value: string);
    /**
     * @stability stable
     */
    get accountKeyPemInput(): string | undefined;
    /**
     * @stability stable
     */
    get certificateDomain(): string;
    /**
     * @stability stable
     */
    get certificateP12(): string;
    private _certificateP12Password?;
    /**
     * @stability stable
     */
    get certificateP12Password(): string;
    /**
     * @stability stable
     */
    set certificateP12Password(value: string);
    /**
     * @stability stable
     */
    resetCertificateP12Password(): void;
    /**
     * @stability stable
     */
    get certificateP12PasswordInput(): string | undefined;
    /**
     * @stability stable
     */
    get certificatePem(): string;
    private _certificateRequestPem?;
    /**
     * @stability stable
     */
    get certificateRequestPem(): string;
    /**
     * @stability stable
     */
    set certificateRequestPem(value: string);
    /**
     * @stability stable
     */
    resetCertificateRequestPem(): void;
    /**
     * @stability stable
     */
    get certificateRequestPemInput(): string | undefined;
    /**
     * @stability stable
     */
    get certificateUrl(): string;
    private _commonName?;
    /**
     * @stability stable
     */
    get commonName(): string;
    /**
     * @stability stable
     */
    set commonName(value: string);
    /**
     * @stability stable
     */
    resetCommonName(): void;
    /**
     * @stability stable
     */
    get commonNameInput(): string | undefined;
    private _disableCompletePropagation?;
    /**
     * @stability stable
     */
    get disableCompletePropagation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set disableCompletePropagation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDisableCompletePropagation(): void;
    /**
     * @stability stable
     */
    get disableCompletePropagationInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get issuerPem(): string;
    private _keyType?;
    /**
     * @stability stable
     */
    get keyType(): string;
    /**
     * @stability stable
     */
    set keyType(value: string);
    /**
     * @stability stable
     */
    resetKeyType(): void;
    /**
     * @stability stable
     */
    get keyTypeInput(): string | undefined;
    private _minDaysRemaining?;
    /**
     * @stability stable
     */
    get minDaysRemaining(): number;
    /**
     * @stability stable
     */
    set minDaysRemaining(value: number);
    /**
     * @stability stable
     */
    resetMinDaysRemaining(): void;
    /**
     * @stability stable
     */
    get minDaysRemainingInput(): number | undefined;
    private _mustStaple?;
    /**
     * @stability stable
     */
    get mustStaple(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mustStaple(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMustStaple(): void;
    /**
     * @stability stable
     */
    get mustStapleInput(): boolean | cdktf.IResolvable | undefined;
    private _preCheckDelay?;
    /**
     * @stability stable
     */
    get preCheckDelay(): number;
    /**
     * @stability stable
     */
    set preCheckDelay(value: number);
    /**
     * @stability stable
     */
    resetPreCheckDelay(): void;
    /**
     * @stability stable
     */
    get preCheckDelayInput(): number | undefined;
    private _preferredChain?;
    /**
     * @stability stable
     */
    get preferredChain(): string;
    /**
     * @stability stable
     */
    set preferredChain(value: string);
    /**
     * @stability stable
     */
    resetPreferredChain(): void;
    /**
     * @stability stable
     */
    get preferredChainInput(): string | undefined;
    /**
     * @stability stable
     */
    get privateKeyPem(): string;
    private _recursiveNameservers?;
    /**
     * @stability stable
     */
    get recursiveNameservers(): string[];
    /**
     * @stability stable
     */
    set recursiveNameservers(value: string[]);
    /**
     * @stability stable
     */
    resetRecursiveNameservers(): void;
    /**
     * @stability stable
     */
    get recursiveNameserversInput(): string[] | undefined;
    private _revokeCertificateOnDestroy?;
    /**
     * @stability stable
     */
    get revokeCertificateOnDestroy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set revokeCertificateOnDestroy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRevokeCertificateOnDestroy(): void;
    /**
     * @stability stable
     */
    get revokeCertificateOnDestroyInput(): boolean | cdktf.IResolvable | undefined;
    private _subjectAlternativeNames?;
    /**
     * @stability stable
     */
    get subjectAlternativeNames(): string[];
    /**
     * @stability stable
     */
    set subjectAlternativeNames(value: string[]);
    /**
     * @stability stable
     */
    resetSubjectAlternativeNames(): void;
    /**
     * @stability stable
     */
    get subjectAlternativeNamesInput(): string[] | undefined;
    private _dnsChallenge?;
    /**
     * @stability stable
     */
    get dnsChallenge(): CertificateDnsChallenge[];
    /**
     * @stability stable
     */
    set dnsChallenge(value: CertificateDnsChallenge[]);
    /**
     * @stability stable
     */
    resetDnsChallenge(): void;
    /**
     * @stability stable
     */
    get dnsChallengeInput(): CertificateDnsChallenge[] | undefined;
    private _httpChallenge;
    /**
     * @stability stable
     */
    get httpChallenge(): CertificateHttpChallengeOutputReference;
    /**
     * @stability stable
     */
    putHttpChallenge(value: CertificateHttpChallenge): void;
    /**
     * @stability stable
     */
    resetHttpChallenge(): void;
    /**
     * @stability stable
     */
    get httpChallengeInput(): CertificateHttpChallenge | undefined;
    private _httpMemcachedChallenge;
    /**
     * @stability stable
     */
    get httpMemcachedChallenge(): CertificateHttpMemcachedChallengeOutputReference;
    /**
     * @stability stable
     */
    putHttpMemcachedChallenge(value: CertificateHttpMemcachedChallenge): void;
    /**
     * @stability stable
     */
    resetHttpMemcachedChallenge(): void;
    /**
     * @stability stable
     */
    get httpMemcachedChallengeInput(): CertificateHttpMemcachedChallenge | undefined;
    private _httpWebrootChallenge;
    /**
     * @stability stable
     */
    get httpWebrootChallenge(): CertificateHttpWebrootChallengeOutputReference;
    /**
     * @stability stable
     */
    putHttpWebrootChallenge(value: CertificateHttpWebrootChallenge): void;
    /**
     * @stability stable
     */
    resetHttpWebrootChallenge(): void;
    /**
     * @stability stable
     */
    get httpWebrootChallengeInput(): CertificateHttpWebrootChallenge | undefined;
    private _tlsChallenge;
    /**
     * @stability stable
     */
    get tlsChallenge(): CertificateTlsChallengeOutputReference;
    /**
     * @stability stable
     */
    putTlsChallenge(value: CertificateTlsChallenge): void;
    /**
     * @stability stable
     */
    resetTlsChallenge(): void;
    /**
     * @stability stable
     */
    get tlsChallengeInput(): CertificateTlsChallenge | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
