import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RegistrationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/registration.html#account_key_pem Registration#account_key_pem}.
     *
     * @stability stable
     */
    readonly accountKeyPem: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/registration.html#email_address Registration#email_address}.
     *
     * @stability stable
     */
    readonly emailAddress: string;
    /**
     * external_account_binding block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/registration.html#external_account_binding Registration#external_account_binding}
     *
     * @stability stable
     */
    readonly externalAccountBinding?: RegistrationExternalAccountBinding;
}
/**
 * @stability stable
 */
export interface RegistrationExternalAccountBinding {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/registration.html#hmac_base64 Registration#hmac_base64}.
     *
     * @stability stable
     */
    readonly hmacBase64: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/registration.html#key_id Registration#key_id}.
     *
     * @stability stable
     */
    readonly keyId: string;
}
export declare function registrationExternalAccountBindingToTerraform(struct?: RegistrationExternalAccountBindingOutputReference | RegistrationExternalAccountBinding): any;
/**
 * @stability stable
 */
export declare class RegistrationExternalAccountBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): RegistrationExternalAccountBinding | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: RegistrationExternalAccountBinding | undefined);
    private _hmacBase64?;
    /**
     * @stability stable
     */
    get hmacBase64(): string;
    /**
     * @stability stable
     */
    set hmacBase64(value: string);
    /**
     * @stability stable
     */
    get hmacBase64Input(): string | undefined;
    private _keyId?;
    /**
     * @stability stable
     */
    get keyId(): string;
    /**
     * @stability stable
     */
    set keyId(value: string);
    /**
     * @stability stable
     */
    get keyIdInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/acme/r/registration.html acme_registration}.
 *
 * @stability stable
 */
export declare class Registration extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/acme/r/registration.html acme_registration} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RegistrationConfig);
    private _accountKeyPem?;
    /**
     * @stability stable
     */
    get accountKeyPem(): string;
    /**
     * @stability stable
     */
    set accountKeyPem(value: string);
    /**
     * @stability stable
     */
    get accountKeyPemInput(): string | undefined;
    private _emailAddress?;
    /**
     * @stability stable
     */
    get emailAddress(): string;
    /**
     * @stability stable
     */
    set emailAddress(value: string);
    /**
     * @stability stable
     */
    get emailAddressInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get registrationUrl(): string;
    private _externalAccountBinding;
    /**
     * @stability stable
     */
    get externalAccountBinding(): RegistrationExternalAccountBindingOutputReference;
    /**
     * @stability stable
     */
    putExternalAccountBinding(value: RegistrationExternalAccountBinding): void;
    /**
     * @stability stable
     */
    resetExternalAccountBinding(): void;
    /**
     * @stability stable
     */
    get externalAccountBindingInput(): RegistrationExternalAccountBinding | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
